@@ -146,10 +146,23 @@
 #endif
 
 #if defined(__arm__) || defined(_M_ARM)
+/*
+ * 32-bit instruction set on, e.g., ARMv7 or AArch32 execution state
+ * on ARMv8
+ */
 #   define NVCPU_ARM
 #   define NVCPU_MIN_PAGE_SHIFT 12
 #endif
 
+#if defined(__aarch64__)
+#   define NVCPU_AARCH64           /* 64-bit A64 instruction set on ARMv8 */
+#   define NVCPU_MIN_PAGE_SHIFT 12
+#endif
+
+#if defined(NVCPU_ARM) || defined(NVCPU_AARCH64)
+#   define NVCPU_FAMILY_ARM
+#endif
+
 #if defined(__SH4__)
 #   ifndef NVCPU_SH4
 #   define NVCPU_SH4               /* Renesas (formerly Hitachi) SH4 */
@@ -181,7 +194,8 @@
 #define NVCPU_MIN_PAGE_SIZE (1 << NVCPU_MIN_PAGE_SHIFT)
 #endif
 
-#if defined(NVCPU_IA64) || defined(NVCPU_X86_64) || defined(NV_MACINTOSH_64)
+#if defined(NVCPU_IA64) || defined(NVCPU_X86_64) || \
+    defined(NV_MACINTOSH_64) || defined(NVCPU_AARCH64)
 #   define NV_64_BITS          /* all architectures where pointers are 64 bits */
 #else
 /* we assume 32 bits. I don't see a need for NV_16_BITS. */
@@ -309,6 +323,16 @@
 #else
 #define NVCPU_IS_ARM 0
 #endif
+#if defined(NVCPU_AARCH64)
+#define NVCPU_IS_AARCH64 1
+#else
+#define NVCPU_IS_AARCH64 0
+#endif
+#if defined(NVCPU_FAMILY_ARM)
+#define NVCPU_IS_FAMILY_ARM 1
+#else
+#define NVCPU_IS_FAMILY_ARM 0
+#endif
 #if defined(NVCPU_SH4)
 #define NVCPU_IS_SH4 1
 #else
